use Test::More tests => 1;

BEGIN {
use_ok( 'Syntax::Highlight::Engine::Simple::Perl' );
}

diag( "Testing Syntax::Highlight::Engine::Simple::Perl $Syntax::Highlight::Engine::Simple::Perl::VERSION" );
